summaryrefslogtreecommitdiff
path: root/plugins/wimaxasncp/packet-wimaxasncp.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/wimaxasncp/packet-wimaxasncp.c')
-rw-r--r--plugins/wimaxasncp/packet-wimaxasncp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/wimaxasncp/packet-wimaxasncp.c b/plugins/wimaxasncp/packet-wimaxasncp.c
index f22dfa9f78..be4cd986b1 100644
--- a/plugins/wimaxasncp/packet-wimaxasncp.c
+++ b/plugins/wimaxasncp/packet-wimaxasncp.c
@@ -3466,12 +3466,12 @@ proto_reg_handoff_wimaxasncp(void)
if (!inited)
{
/* Use new_create_dissector_handle() to indicate that
* dissect_wimaxasncp() returns the number of bytes it dissected (or
* 0 if it thinks the packet does not belong to WiMAX ASN Control
* Plane).
*/
- wimaxasncp_handle = new_create_dissector_handle(
+ wimaxasncp_handle = create_dissector_handle(
dissect_wimaxasncp,
proto_wimaxasncp);
@@ -3466,12 +3466,12 @@ proto_reg_handoff_wimaxasncp(void)
if (!inited)
{
- /* Use new_create_dissector_handle() to indicate that
+ /* Use create_dissector_handle() to indicate that
* dissect_wimaxasncp() returns the number of bytes it dissected (or
* 0 if it thinks the packet does not belong to WiMAX ASN Control